import React, { ReactNode } from "react";

import { EventSetting } from "./EventSetting";

import styles from "./MiniEventCard.module.css";

interface Props {
  name: string;
  description: ReactNode;
  short: string;
  online: boolean;
  location: string;
  date: Date;
}

export const MiniEventCard: React.FC<Props> = ({
  name,
  short,
  description,
  location,
  date,
  online,
}) => {
  return (
    <details className={styles.card}>
      <summary>
        <div onClick={(event) => event.preventDefault()}>
          <h2 className={styles.name}>
            <div>{name}</div>
            <div className={styles.nameSpacer}></div>
          </h2>
          <div className={styles.info}>
            <EventSetting date={date} location={location} online={online} />
          </div>
          <p className={styles.shortDescription}>{short}</p>
        </div>
        <div className={styles.details}>View details {dropDownIcon}</div>
      </summary>
      <div>{description}</div>
    </details>
  );
};

const dropDownIcon = (
  <svg
    xmlns="http://www.w3.org/2000/svg"
    width="14"
    height="9"
    viewBox="0 0 14 9"
    className={styles.dropDownIcon}
  >
    <path d="M6.24407 8.12713C6.64284 8.58759 7.35716 8.58759 7.75593 8.12713L13.3613 1.65465C13.9221 1.00701 13.4621 0 12.6053 0H1.39467C0.537918 0 0.0778675 1.00701 0.638743 1.65465L6.24407 8.12713Z" />
  </svg>
);
